pub struct ExecServerRuntimePaths {
pub codex_self_exe: AbsolutePathBuf,
pub codex_linux_sandbox_exe: Option<AbsolutePathBuf>,
}Expand description
Runtime paths needed by exec-server child processes.
Fields
codex_self_exe: AbsolutePathBufStable path to the Codex executable used to launch hidden helper modes.
codex_linux_sandbox_exe: Option<AbsolutePathBuf>Path to the Linux sandbox helper alias used when the platform sandbox needs to re-enter Codex by argv0.
Implementations