NoiseChannelPublicKey

Struct NoiseChannelPublicKey 

pub struct NoiseChannelPublicKey { /* private fields */ }
Public key material for the exec-server Noise suite. The suite tag prevents keys for another protocol from being accepted just because their components have the expected lengths.