pub trait EnvironmentProvider: Send + Sync {
// Required method
fn snapshot(&self) -> EnvironmentProviderFuture<'_>;
}Expand description
Lists the concrete environments available to Codex.
Implementations own a startup snapshot containing both the available
environment list in configured order and the default environment
selection. Providers should only return provider-owned remote environments;
include_local controls whether EnvironmentManager should add the local
environment to the snapshot.
Required Methods
Sourcefn snapshot(&self) -> EnvironmentProviderFuture<'_>
fn snapshot(&self) -> EnvironmentProviderFuture<'_>
Returns the provider-owned environment startup snapshot.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".